@@ -9,7 +9,7 @@ use oEdtk::DBAdmin 		qw(db_connect csv_import);
 
 
 if (@ARGV < 1) {
-	die "Usage: $0 <acq.csv>\n";
+	die "Usage: $0 <acq_file>\n";
 }
 
 my $cfg = config_read('EDTK_DB');
@@ -18,7 +18,7 @@ my $dbh = db_connect($cfg, 'EDTK_DBI_DSN',
 
 csv_import($dbh, "EDTK_ACQ", $ARGV[0], 
 			{ mode => 'merge', 
-			header => 'ED_SEQLOT,ED_LOTNAME,ED_DTPRINT,ED_DTPOST,ED_NBPGLOT,ED_NBPLISLOT,ED_DTPOST2' }
+			header => 'ED_SEQLOT,ED_LOTNAME,ED_DTPRINT,ED_DTPOST,ED_NBFACES,ED_NBPLIS,ED_DTPOST2' }
 			);
 
 1;
\ No newline at end of file
